@@ -1,7 +1,7 @@
 (*---------------------------------------------------------------------------
-   Copyright (c) 2011-2012 Daniel C. Bünzli. All rights reserved.
+   Copyright (c) 2011 Daniel C. Bünzli. All rights reserved.
    Distributed under a BSD3 license, see license at the end of the file.
-   cmdliner release 0.9.3
+   cmdliner release 0.9.4
   ---------------------------------------------------------------------------*)
 
 (* Invalid_arg strings *)
@@ -39,7 +39,8 @@ let pr_to_temp_file pr v = try
   let exec = Filename.basename Sys.argv.(0) in
   let file, oc = Filename.open_temp_file exec "out" in
   let ppf = Format.formatter_of_out_channel oc in
-  pr ppf v; Format.pp_print_flush ppf (); close_out oc; 
+  pr ppf v; Format.pp_print_flush ppf (); close_out oc;
+  at_exit (fun () -> try Sys.remove file with Sys_error e -> ());
   Some file
 with Sys_error _ -> None
 
@@ -153,7 +154,12 @@ type arg_info =                (* information about a command line argument. *)
       o_names : string list;                        (* names (for opt args). *)
       o_all : bool; }                          (* repeatable (for opt args). *)
 
-let arg_id () = Oo.id (object end)                      (* thread-safe UIDs. *)
+let arg_id =        (* thread-safe UIDs, Oo.id (object end) was used before. *)
+  let c = ref 0 in
+  fun () -> 
+    let id = !c in 
+    incr c; if id > !c then assert false (* too many ids *) else id
+    
 let is_opt a = a.o_names <> []
 let is_pos a = a.o_names = []
 
@@ -301,6 +307,7 @@ module Manpage = struct
     let pager = 
       let cmds = ["less"; "more"] in
       let cmds = try (Sys.getenv "PAGER") :: cmds with Not_found -> cmds in
+      let cmds = try (Sys.getenv "MANPAGER") :: cmds with Not_found -> cmds in
       find_cmd cmds
     in
     match pager with 
@@ -1184,7 +1191,7 @@ module Term = struct
 end
 
 (*---------------------------------------------------------------------------
-   Copyright (c) 2011-2012 Daniel C. Bünzli
+   Copyright (c) 2011 Daniel C. Bünzli
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
