@@ -1,7 +1,7 @@
 (*---------------------------------------------------------------------------
-   Copyright (c) 2011-2012 Daniel C. Bünzli. All rights reserved.
+   Copyright (c) 2011 Daniel C. Bünzli. All rights reserved.
    Distributed under a BSD3 license, see license at the end of the file.
-   cmdliner release 0.9.3
+   cmdliner release 0.9.4
   ---------------------------------------------------------------------------*)
 
 (** Declarative definition of command line interfaces.
@@ -22,7 +22,7 @@
     use. Open the module to use it, it defines only three modules in
     your scope.
 
-    {e Release 0.9.3 - Daniel Bünzli <daniel.buenzli at erratique.ch> } *)
+    {e Release 0.9.4 - Daniel Bünzli <daniel.buenzl i\@erratique.ch> } *)
 
 (** {1:top Interface} *)
 
@@ -1085,7 +1085,7 @@ let () = match Term.eval_choice default_cmd cmds with
 *)
 
 (*---------------------------------------------------------------------------
-   Copyright (c) 2011-2012 Daniel C. Bünzli
+   Copyright (c) 2011 Daniel C. Bünzli
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
